Module seeding

Module seeding 

Structs

SeedConfig

Enums

SeedRiskProfile

Functions

generate_rho_candidates
select_objective_seed_on_log_lambda_grid
Choose an initial log-smoothing vector by evaluating the same objective the outer optimizer will minimize on a small deterministic grid around the analytic/heuristic seed.