pub struct DuchonSplineBasis {
pub basis: Array2<f64>,
pub penalty_kernel: Array2<f64>,
pub penalty_ridge: Array2<f64>,
pub num_kernel_basis: usize,
pub num_polynomial_basis: usize,
pub dimension: usize,
pub nullspace_order: DuchonNullspaceOrder,
}Expand description
Duchon radial basis with triple operator regularization and explicit low-frequency null-space order. The penalty blocks are collocation operator Gram matrices, not the native spectral Duchon seminorm.
Fields
basis: Array2<f64>penalty_kernel: Array2<f64>penalty_ridge: Array2<f64>num_kernel_basis: usizenum_polynomial_basis: usizedimension: usizenullspace_order: DuchonNullspaceOrderTrait Implementations
Sourceimpl Clone for DuchonSplineBasis
impl Clone for DuchonSplineBasis
Sourcefn clone(&self) -> DuchonSplineBasis
fn clone(&self) -> DuchonSplineBasis
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for DuchonSplineBasis
impl RefUnwindSafe for DuchonSplineBasis
impl Send for DuchonSplineBasis
impl Sync for DuchonSplineBasis
impl Unpin for DuchonSplineBasis
impl UnsafeUnpin for DuchonSplineBasis
impl UnwindSafe for DuchonSplineBasis