#[repr(transparent)]pub struct LogSmoothingParamsView<'a>(pub ArrayView1<'a, f64>);Tuple Fields
0: ArrayView1<'a, f64>Implementations
Methods from Deref<Target = ArrayRef<<S as RawData>::Elem, D>>
Sourcepub fn to_owned(&self) -> ArrayBase<OwnedRepr<A>, D>where
A: Clone,
pub fn to_owned(&self) -> ArrayBase<OwnedRepr<A>, D>where
A: Clone,
Return an uniquely owned copy of the array.
If the input array is contiguous, then the output array will have the same
memory layout. Otherwise, the layout of the output array is unspecified.
If you need a particular layout, you can allocate a new array with the
desired memory layout and .assign() the data.
Alternatively, you can collect an iterator, like this for a result in
standard layout:
Array::from_shape_vec(arr.raw_dim(), arr.iter().cloned().collect()).unwrap()or this for a result in column-major (Fortran) layout:
Array::from_shape_vec(arr.raw_dim().f(), arr.t().iter().cloned().collect()).unwrap()Sourcepub fn first(&self) -> Option<&A>
pub fn first(&self) -> Option<&A>
Returns a reference to the first element of the array, or None if it
is empty.
Example
use ndarray::Array3;
let mut a = Array3::<f64>::zeros([3, 4, 2]);
a[[0, 0, 0]] = 42.;
assert_eq!(a.first(), Some(&42.));
let b = Array3::<f64>::zeros([3, 0, 5]);
assert_eq!(b.first(), None);Sourcepub fn last(&self) -> Option<&A>
pub fn last(&self) -> Option<&A>
Returns a reference to the last element of the array, or None if it
is empty.
Example
use ndarray::Array3;
let mut a = Array3::<f64>::zeros([3, 4, 2]);
a[[2, 3, 1]] = 42.;
assert_eq!(a.last(), Some(&42.));
let b = Array3::<f64>::zeros([3, 0, 5]);
assert_eq!(b.last(), None);Sourcepub fn iter(&self) -> Iter<'_, A, D>
pub fn iter(&self) -> Iter<'_, A, D>
Return an iterator of references to the elements of the array.
Elements are visited in the logical order of the array, which is where the rightmost index is varying the fastest.
Iterator element type is &A.
Sourcepub fn indexed_iter(&self) -> IndexedIter<'_, A, D>
pub fn indexed_iter(&self) -> IndexedIter<'_, A, D>
Return an iterator of indexes and references to the elements of the array.
Elements are visited in the logical order of the array, which is where the rightmost index is varying the fastest.
Iterator element type is (D::Pattern, &A).
See also Zip::indexed
Sourcepub fn slice<I>(
&self,
info: I,
) -> ArrayBase<ViewRepr<&A>, <I as SliceArg<D>>::OutDim>where
I: SliceArg<D>,
pub fn slice<I>(
&self,
info: I,
) -> ArrayBase<ViewRepr<&A>, <I as SliceArg<D>>::OutDim>where
I: SliceArg<D>,
Sourcepub fn slice_axis(
&self,
axis: Axis,
indices: Slice,
) -> ArrayBase<ViewRepr<&A>, D>
pub fn slice_axis( &self, axis: Axis, indices: Slice, ) -> ArrayBase<ViewRepr<&A>, D>
Return a view of the array, sliced along the specified axis.
Panics if an index is out of bounds or step size is zero.
Panics if axis is out of bounds.
Sourcepub fn slice_each_axis<F>(&self, f: F) -> ArrayBase<ViewRepr<&A>, D>
pub fn slice_each_axis<F>(&self, f: F) -> ArrayBase<ViewRepr<&A>, D>
Return a view of a slice of the array, with a closure specifying the slice for each axis.
This is especially useful for code which is generic over the dimensionality of the array.
Panics if an index is out of bounds or step size is zero.
Sourcepub fn get<I>(&self, index: I) -> Option<&A>where
I: NdIndex<D>,
pub fn get<I>(&self, index: I) -> Option<&A>where
I: NdIndex<D>,
Return a reference to the element at index, or return None
if the index is out of bounds.
Arrays also support indexing syntax: array[index].
use ndarray::arr2;
let a = arr2(&[[1., 2.],
[3., 4.]]);
assert!(
a.get((0, 1)) == Some(&2.) &&
a.get((0, 2)) == None &&
a[(0, 1)] == 2. &&
a[[0, 1]] == 2.
);Sourcepub unsafe fn uget<I>(&self, index: I) -> &Awhere
I: NdIndex<D>,
pub unsafe fn uget<I>(&self, index: I) -> &Awhere
I: NdIndex<D>,
Perform unchecked array indexing.
Return a reference to the element at index.
Note: only unchecked for non-debug builds of ndarray.
Safety
The caller must ensure that the index is in-bounds.
Sourcepub fn index_axis(
&self,
axis: Axis,
index: usize,
) -> ArrayBase<ViewRepr<&A>, <D as Dimension>::Smaller>where
D: RemoveAxis,
pub fn index_axis(
&self,
axis: Axis,
index: usize,
) -> ArrayBase<ViewRepr<&A>, <D as Dimension>::Smaller>where
D: RemoveAxis,
Returns a view restricted to index along the axis, with the axis
removed.
See Subviews for full documentation.
Panics if axis or index is out of bounds.
use ndarray::{arr2, ArrayView, Axis};
let a = arr2(&[[1., 2. ], // ... axis 0, row 0
[3., 4. ], // --- axis 0, row 1
[5., 6. ]]); // ... axis 0, row 2
// . \
// . axis 1, column 1
// axis 1, column 0
assert!(
a.index_axis(Axis(0), 1) == ArrayView::from(&[3., 4.]) &&
a.index_axis(Axis(1), 1) == ArrayView::from(&[2., 4., 6.])
);Sourcepub fn select(
&self,
axis: Axis,
indices: &[usize],
) -> ArrayBase<OwnedRepr<A>, D>where
A: Clone,
D: RemoveAxis,
pub fn select(
&self,
axis: Axis,
indices: &[usize],
) -> ArrayBase<OwnedRepr<A>, D>where
A: Clone,
D: RemoveAxis,
Along axis, select arbitrary subviews corresponding to indices
and copy them into a new array.
Panics if axis or an element of indices is out of bounds.
use ndarray::{arr2, Axis};
let x = arr2(&[[0., 1.],
[2., 3.],
[4., 5.],
[6., 7.],
[8., 9.]]);
let r = x.select(Axis(0), &[0, 4, 3]);
assert!(
r == arr2(&[[0., 1.],
[8., 9.],
[6., 7.]])
);Sourcepub fn rows(&self) -> Lanes<'_, A, <D as Dimension>::Smaller>
pub fn rows(&self) -> Lanes<'_, A, <D as Dimension>::Smaller>
Return a producer and iterable that traverses over the generalized rows of the array. For a 2D array these are the regular rows.
This is equivalent to .lanes(Axis(n - 1)) where n is self.ndim().
For an array of dimensions a × b × c × … × l × m it has a × b × c × … × l rows each of length m.
For example, in a 2 × 2 × 3 array, each row is 3 elements long and there are 2 × 2 = 4 rows in total.
Iterator element is ArrayView1<A> (1D array view).
use ndarray::arr3;
let a = arr3(&[[[ 0, 1, 2], // -- row 0, 0
[ 3, 4, 5]], // -- row 0, 1
[[ 6, 7, 8], // -- row 1, 0
[ 9, 10, 11]]]); // -- row 1, 1
// `rows` will yield the four generalized rows of the array.
for row in a.rows() {
/* loop body */
}Sourcepub fn columns(&self) -> Lanes<'_, A, <D as Dimension>::Smaller>
pub fn columns(&self) -> Lanes<'_, A, <D as Dimension>::Smaller>
Return a producer and iterable that traverses over the generalized columns of the array. For a 2D array these are the regular columns.
This is equivalent to .lanes(Axis(0)).
For an array of dimensions a × b × c × … × l × m it has b × c × … × l × m columns each of length a.
For example, in a 2 × 2 × 3 array, each column is 2 elements long and there are 2 × 3 = 6 columns in total.
Iterator element is ArrayView1<A> (1D array view).
use ndarray::arr3;
// The generalized columns of a 3D array:
// are directed along the 0th axis: 0 and 6, 1 and 7 and so on...
let a = arr3(&[[[ 0, 1, 2], [ 3, 4, 5]],
[[ 6, 7, 8], [ 9, 10, 11]]]);
// Here `columns` will yield the six generalized columns of the array.
for column in a.columns() {
/* loop body */
}Sourcepub fn lanes(&self, axis: Axis) -> Lanes<'_, A, <D as Dimension>::Smaller>
pub fn lanes(&self, axis: Axis) -> Lanes<'_, A, <D as Dimension>::Smaller>
Return a producer and iterable that traverses over all 1D lanes
pointing in the direction of axis.
When pointing in the direction of the first axis, they are columns, in the direction of the last axis rows; in general they are all lanes and are one dimensional.
Iterator element is ArrayView1<A> (1D array view).
use ndarray::{arr3, aview1, Axis};
let a = arr3(&[[[ 0, 1, 2],
[ 3, 4, 5]],
[[ 6, 7, 8],
[ 9, 10, 11]]]);
let inner0 = a.lanes(Axis(0));
let inner1 = a.lanes(Axis(1));
let inner2 = a.lanes(Axis(2));
// The first lane for axis 0 is [0, 6]
assert_eq!(inner0.into_iter().next().unwrap(), aview1(&[0, 6]));
// The first lane for axis 1 is [0, 3]
assert_eq!(inner1.into_iter().next().unwrap(), aview1(&[0, 3]));
// The first lane for axis 2 is [0, 1, 2]
assert_eq!(inner2.into_iter().next().unwrap(), aview1(&[0, 1, 2]));Sourcepub fn outer_iter(&self) -> AxisIter<'_, A, <D as Dimension>::Smaller>where
D: RemoveAxis,
pub fn outer_iter(&self) -> AxisIter<'_, A, <D as Dimension>::Smaller>where
D: RemoveAxis,
Return an iterator that traverses over the outermost dimension and yields each subview.
This is equivalent to .axis_iter(Axis(0)).
Iterator element is ArrayView<A, D::Smaller> (read-only array view).
Sourcepub fn axis_iter(
&self,
axis: Axis,
) -> AxisIter<'_, A, <D as Dimension>::Smaller>where
D: RemoveAxis,
pub fn axis_iter(
&self,
axis: Axis,
) -> AxisIter<'_, A, <D as Dimension>::Smaller>where
D: RemoveAxis,
Return an iterator that traverses over axis
and yields each subview along it.
For example, in a 3 × 4 × 5 array, with axis equal to Axis(2),
the iterator element
is a 3 × 4 subview (and there are 5 in total), as shown
in the picture below.
Iterator element is ArrayView<A, D::Smaller> (read-only array view).
See Subviews for full documentation.
Panics if axis is out of bounds.
Sourcepub fn axis_chunks_iter(
&self,
axis: Axis,
size: usize,
) -> AxisChunksIter<'_, A, D>
pub fn axis_chunks_iter( &self, axis: Axis, size: usize, ) -> AxisChunksIter<'_, A, D>
Return an iterator that traverses over axis by chunks of size,
yielding non-overlapping views along that axis.
Iterator element is ArrayView<A, D>
The last view may have less elements if size does not divide
the axis’ dimension.
Panics if axis is out of bounds or if size is zero.
use ndarray::Array;
use ndarray::{arr3, Axis};
let a = Array::from_iter(0..28).into_shape_with_order((2, 7, 2)).unwrap();
let mut iter = a.axis_chunks_iter(Axis(1), 2);
// first iteration yields a 2 × 2 × 2 view
assert_eq!(iter.next().unwrap(),
arr3(&[[[ 0, 1], [ 2, 3]],
[[14, 15], [16, 17]]]));
// however the last element is a 2 × 1 × 2 view since 7 % 2 == 1
assert_eq!(iter.next_back().unwrap(), arr3(&[[[12, 13]],
[[26, 27]]]));Sourcepub fn exact_chunks<E>(&self, chunk_size: E) -> ExactChunks<'_, A, D>where
E: IntoDimension<Dim = D>,
pub fn exact_chunks<E>(&self, chunk_size: E) -> ExactChunks<'_, A, D>where
E: IntoDimension<Dim = D>,
Return an exact chunks producer (and iterable).
It produces the whole chunks of a given n-dimensional chunk size, skipping the remainder along each dimension that doesn’t fit evenly.
The produced element is a ArrayView<A, D> with exactly the dimension
chunk_size.
Panics if any dimension of chunk_size is zero
(Panics if D is IxDyn and chunk_size does not match the
number of array axes.)
Sourcepub fn windows<E>(&self, window_size: E) -> Windows<'_, A, D>where
E: IntoDimension<Dim = D>,
pub fn windows<E>(&self, window_size: E) -> Windows<'_, A, D>where
E: IntoDimension<Dim = D>,
Return a window producer and iterable.
The windows are all distinct overlapping views of size window_size
that fit into the array’s shape.
This is essentially equivalent to ArrayRef::windows_with_stride() with unit stride.
Sourcepub fn windows_with_stride<E>(
&self,
window_size: E,
stride: E,
) -> Windows<'_, A, D>where
E: IntoDimension<Dim = D>,
pub fn windows_with_stride<E>(
&self,
window_size: E,
stride: E,
) -> Windows<'_, A, D>where
E: IntoDimension<Dim = D>,
Return a window producer and iterable.
The windows are all distinct views of size window_size
that fit into the array’s shape.
The stride is ordered by the outermost axis.
Hence, a (x₀, x₁, …, xₙ) stride will be applied to
(A₀, A₁, …, Aₙ) where Aₓ stands for Axis(x).
This produces all windows that fit within the array for the given stride, assuming the window size is not larger than the array size.
The produced element is an ArrayView<A, D> with exactly the dimension
window_size.
Note that passing a stride of only ones is similar to
calling ArrayRef::windows().
Panics if any dimension of window_size or stride is zero.
(Panics if D is IxDyn and window_size or stride does not match the
number of array axes.)
This is the same illustration found in ArrayRef::windows(),
2×2 windows in a 3×4 array, but now with a (1, 2) stride:
──▶ Axis(1)
│ ┏━━━━━┳━━━━━┱─────┬─────┐ ┌─────┬─────┲━━━━━┳━━━━━┓
▼ ┃ a₀₀ ┃ a₀₁ ┃ │ │ │ │ ┃ a₀₂ ┃ a₀₃ ┃
Axis(0) ┣━━━━━╋━━━━━╉─────┼─────┤ ├─────┼─────╊━━━━━╋━━━━━┫
┃ a₁₀ ┃ a₁₁ ┃ │ │ │ │ ┃ a₁₂ ┃ a₁₃ ┃
┡━━━━━╇━━━━━╃─────┼─────┤ ├─────┼─────╄━━━━━╇━━━━━┩
│ │ │ │ │ │ │ │ │ │
└─────┴─────┴─────┴─────┘ └─────┴─────┴─────┴─────┘
┌─────┬─────┬─────┬─────┐ ┌─────┬─────┬─────┬─────┐
│ │ │ │ │ │ │ │ │ │
┢━━━━━╈━━━━━╅─────┼─────┤ ├─────┼─────╆━━━━━╈━━━━━┪
┃ a₁₀ ┃ a₁₁ ┃ │ │ │ │ ┃ a₁₂ ┃ a₁₃ ┃
┣━━━━━╋━━━━━╉─────┼─────┤ ├─────┼─────╊━━━━━╋━━━━━┫
┃ a₂₀ ┃ a₂₁ ┃ │ │ │ │ ┃ a₂₂ ┃ a₂₃ ┃
┗━━━━━┻━━━━━┹─────┴─────┘ └─────┴─────┺━━━━━┻━━━━━┛Sourcepub fn axis_windows(
&self,
axis: Axis,
window_size: usize,
) -> AxisWindows<'_, A, D>
pub fn axis_windows( &self, axis: Axis, window_size: usize, ) -> AxisWindows<'_, A, D>
Returns a producer which traverses over all windows of a given length along an axis.
The windows are all distinct, possibly-overlapping views. The shape of each window
is the shape of self, with the length of axis replaced with window_size.
Panics if axis is out-of-bounds or if window_size is zero.
use ndarray::{Array3, Axis, s};
let arr = Array3::from_shape_fn([4, 5, 2], |(i, j, k)| i * 100 + j * 10 + k);
let correct = vec![
arr.slice(s![.., 0..3, ..]),
arr.slice(s![.., 1..4, ..]),
arr.slice(s![.., 2..5, ..]),
];
for (window, correct) in arr.axis_windows(Axis(1), 3).into_iter().zip(&correct) {
assert_eq!(window, correct);
assert_eq!(window.shape(), &[4, 3, 2]);
}Sourcepub fn axis_windows_with_stride(
&self,
axis: Axis,
window_size: usize,
stride_size: usize,
) -> AxisWindows<'_, A, D>
pub fn axis_windows_with_stride( &self, axis: Axis, window_size: usize, stride_size: usize, ) -> AxisWindows<'_, A, D>
Returns a producer which traverses over windows of a given length and stride along an axis.
Note that a calling this method with a stride of 1 is equivalent to
calling ArrayRef::axis_windows().
Sourcepub fn diag(&self) -> ArrayBase<ViewRepr<&A>, Dim<[usize; 1]>>
pub fn diag(&self) -> ArrayBase<ViewRepr<&A>, Dim<[usize; 1]>>
Return a view of the diagonal elements of the array.
The diagonal is simply the sequence indexed by (0, 0, .., 0), (1, 1, …, 1) etc as long as all axes have elements.
Sourcepub fn as_standard_layout(&self) -> ArrayBase<CowRepr<'_, A>, D>where
A: Clone,
pub fn as_standard_layout(&self) -> ArrayBase<CowRepr<'_, A>, D>where
A: Clone,
Return a standard-layout array containing the data, cloning if necessary.
If self is in standard layout, a COW view of the data is returned
without cloning. Otherwise, the data is cloned, and the returned array
owns the cloned data.
use ndarray::Array2;
let standard = Array2::<f64>::zeros((3, 4));
assert!(standard.is_standard_layout());
let cow_view = standard.as_standard_layout();
assert!(cow_view.is_view());
assert!(cow_view.is_standard_layout());
let fortran = standard.reversed_axes();
assert!(!fortran.is_standard_layout());
let cow_owned = fortran.as_standard_layout();
assert!(cow_owned.is_owned());
assert!(cow_owned.is_standard_layout());Sourcepub fn as_slice(&self) -> Option<&[A]>
pub fn as_slice(&self) -> Option<&[A]>
Return the array’s data as a slice, if it is contiguous and in standard order.
Return None otherwise.
If this function returns Some(_), then the element order in the slice
corresponds to the logical order of the array’s elements.
Sourcepub fn as_slice_memory_order(&self) -> Option<&[A]>
pub fn as_slice_memory_order(&self) -> Option<&[A]>
Return the array’s data as a slice if it is contiguous,
return None otherwise.
If this function returns Some(_), then the elements in the slice
have whatever order the elements have in memory.
Sourcepub fn to_shape<E>(
&self,
new_shape: E,
) -> Result<ArrayBase<CowRepr<'_, A>, <E as ShapeArg>::Dim>, ShapeError>
pub fn to_shape<E>( &self, new_shape: E, ) -> Result<ArrayBase<CowRepr<'_, A>, <E as ShapeArg>::Dim>, ShapeError>
Transform the array into new_shape; any shape with the same number of elements is
accepted.
order specifies the logical order in which the array is to be read and reshaped.
The array is returned as a CowArray; a view if possible, otherwise an owned array.
For example, when starting from the one-dimensional sequence 1 2 3 4 5 6, it would be understood as a 2 x 3 array in row major (“C”) order this way:
1 2 3
4 5 6and as 2 x 3 in column major (“F”) order this way:
1 3 5
2 4 6This example should show that any time we “reflow” the elements in the array to a different
number of rows and columns (or more axes if applicable), it is important to pick an index
ordering, and that’s the reason for the function parameter for order.
The new_shape parameter should be a dimension and an optional order like these examples:
(3, 4) // Shape 3 x 4 with default order (RowMajor)
((3, 4), Order::RowMajor)) // use specific order
((3, 4), Order::ColumnMajor)) // use specific order
((3, 4), Order::C)) // use shorthand for order - shorthands C and FErrors if the new shape doesn’t have the same number of elements as the array’s current shape.
Example
use ndarray::array;
use ndarray::Order;
assert!(
array![1., 2., 3., 4., 5., 6.].to_shape(((2, 3), Order::RowMajor)).unwrap()
== array![[1., 2., 3.],
[4., 5., 6.]]
);
assert!(
array![1., 2., 3., 4., 5., 6.].to_shape(((2, 3), Order::ColumnMajor)).unwrap()
== array![[1., 3., 5.],
[2., 4., 6.]]
);Sourcepub fn flatten(&self) -> ArrayBase<CowRepr<'_, A>, Dim<[usize; 1]>>where
A: Clone,
pub fn flatten(&self) -> ArrayBase<CowRepr<'_, A>, Dim<[usize; 1]>>where
A: Clone,
Flatten the array to a one-dimensional array.
The array is returned as a CowArray; a view if possible, otherwise an owned array.
use ndarray::{arr1, arr3};
let array = arr3(&[[[1, 2], [3, 4]], [[5, 6], [7, 8]]]);
let flattened = array.flatten();
assert_eq!(flattened, arr1(&[1, 2, 3, 4, 5, 6, 7, 8]));Sourcepub fn flatten_with_order(
&self,
order: Order,
) -> ArrayBase<CowRepr<'_, A>, Dim<[usize; 1]>>where
A: Clone,
pub fn flatten_with_order(
&self,
order: Order,
) -> ArrayBase<CowRepr<'_, A>, Dim<[usize; 1]>>where
A: Clone,
Flatten the array to a one-dimensional array.
order specifies the logical order in which the array is to be read and reshaped.
The array is returned as a CowArray; a view if possible, otherwise an owned array.
use ndarray::{arr1, arr2};
use ndarray::Order;
let array = arr2(&[[1, 2], [3, 4], [5, 6], [7, 8]]);
let flattened = array.flatten_with_order(Order::RowMajor);
assert_eq!(flattened, arr1(&[1, 2, 3, 4, 5, 6, 7, 8]));
let flattened = array.flatten_with_order(Order::ColumnMajor);
assert_eq!(flattened, arr1(&[1, 3, 5, 7, 2, 4, 6, 8]));Sourcepub fn broadcast<E>(
&self,
dim: E,
) -> Option<ArrayBase<ViewRepr<&A>, <E as IntoDimension>::Dim>>where
E: IntoDimension,
pub fn broadcast<E>(
&self,
dim: E,
) -> Option<ArrayBase<ViewRepr<&A>, <E as IntoDimension>::Dim>>where
E: IntoDimension,
Act like a larger size and/or shape array by broadcasting into a larger shape, if possible.
Return None if shapes can not be broadcast together.
Background
- Two axes are compatible if they are equal, or one of them is 1.
- In this instance, only the axes of the smaller side (self) can be 1.
Compare axes beginning with the last axis of each shape.
For example (1, 2, 4) can be broadcast into (7, 6, 2, 4) because its axes are either equal or 1 (or missing); while (2, 2) can not be broadcast into (2, 4).
The implementation creates a view with strides set to zero for the axes that are to be repeated.
The broadcasting documentation for NumPy has more information.
use ndarray::{aview1, aview2};
assert!(
aview1(&[1., 0.]).broadcast((10, 2)).unwrap()
== aview2(&[[1., 0.]; 10])
);Sourcepub fn t(&self) -> ArrayBase<ViewRepr<&A>, D>
pub fn t(&self) -> ArrayBase<ViewRepr<&A>, D>
Return a transposed view of the array.
This is a shorthand for self.view().reversed_axes().
See also the more general methods .reversed_axes() and .swap_axes().
Sourcepub fn assign_to<P>(&self, to: P)
pub fn assign_to<P>(&self, to: P)
Perform an elementwise assignment of values cloned from self into array or producer to.
The destination to can be another array or a producer of assignable elements.
AssignElem determines how elements are assigned.
Panics if shapes disagree.
Sourcepub fn fold<'a, F, B>(&'a self, init: B, f: F) -> B
pub fn fold<'a, F, B>(&'a self, init: B, f: F) -> B
Traverse the array elements and apply a fold, returning the resulting value.
Elements are visited in arbitrary order.
Sourcepub fn map<'a, B, F>(&'a self, f: F) -> ArrayBase<OwnedRepr<B>, D>
pub fn map<'a, B, F>(&'a self, f: F) -> ArrayBase<OwnedRepr<B>, D>
Call f by reference on each element and create a new array
with the new values.
Elements are visited in arbitrary order.
Return an array with the same shape as self.
use ndarray::arr2;
let a = arr2(&[[ 0., 1.],
[-1., 2.]]);
assert!(
a.map(|x| *x >= 1.0)
== arr2(&[[false, true],
[false, true]])
);Sourcepub fn mapv<B, F>(&self, f: F) -> ArrayBase<OwnedRepr<B>, D>
pub fn mapv<B, F>(&self, f: F) -> ArrayBase<OwnedRepr<B>, D>
Call f by value on each element and create a new array
with the new values.
Elements are visited in arbitrary order.
Return an array with the same shape as self.
use ndarray::arr2;
let a = arr2(&[[ 0., 1.],
[-1., 2.]]);
assert!(
a.mapv(f32::abs) == arr2(&[[0., 1.],
[1., 2.]])
);Sourcepub fn for_each<'a, F>(&'a self, f: F)
pub fn for_each<'a, F>(&'a self, f: F)
Call f for each element in the array.
Elements are visited in arbitrary order.
Sourcepub fn fold_axis<B, F>(
&self,
axis: Axis,
init: B,
fold: F,
) -> ArrayBase<OwnedRepr<B>, <D as Dimension>::Smaller>
pub fn fold_axis<B, F>( &self, axis: Axis, init: B, fold: F, ) -> ArrayBase<OwnedRepr<B>, <D as Dimension>::Smaller>
Fold along an axis.
Combine the elements of each subview with the previous using the fold
function and initial value init.
Return the result as an Array.
Panics if axis is out of bounds.
Sourcepub fn map_axis<'a, B, F>(
&'a self,
axis: Axis,
mapping: F,
) -> ArrayBase<OwnedRepr<B>, <D as Dimension>::Smaller>
pub fn map_axis<'a, B, F>( &'a self, axis: Axis, mapping: F, ) -> ArrayBase<OwnedRepr<B>, <D as Dimension>::Smaller>
Reduce the values along an axis into just one value, producing a new array with one less dimension.
Elements are visited in arbitrary order.
Return the result as an Array.
Panics if axis is out of bounds.
Sourcepub fn partition(&self, kth: usize, axis: Axis) -> ArrayBase<OwnedRepr<A>, D>
pub fn partition(&self, kth: usize, axis: Axis) -> ArrayBase<OwnedRepr<A>, D>
Return a partitioned copy of the array.
Creates a copy of the array and partially sorts it around the k-th element along the given axis. The k-th element will be in its sorted position, with:
- All elements smaller than the k-th element to its left
- All elements equal or greater than the k-th element to its right
- The ordering within each partition is undefined
Empty arrays (i.e., those with any zero-length axes) are considered partitioned already, and will be returned unchanged.
Panics if k is out of bounds for a non-zero axis length.
Parameters
kth- Index to partition by. The k-th element will be in its sorted position.axis- Axis along which to partition.
Examples
use ndarray::prelude::*;
let a = array![7, 1, 5, 2, 6, 0, 3, 4];
let p = a.partition(3, Axis(0));
// The element at position 3 is now 3, with smaller elements to the left
// and greater elements to the right
assert_eq!(p[3], 3);
assert!(p.slice(s![..3]).iter().all(|&x| x <= 3));
assert!(p.slice(s![4..]).iter().all(|&x| x >= 3));Sourcepub fn sum(&self) -> A
pub fn sum(&self) -> A
Return the sum of all elements in the array.
use ndarray::arr2;
let a = arr2(&[[1., 2.],
[3., 4.]]);
assert_eq!(a.sum(), 10.);Sourcepub fn mean(&self) -> Option<A>
pub fn mean(&self) -> Option<A>
Returns the arithmetic mean x̅ of all elements in the array:
1 n
x̅ = ― ∑ xᵢ
n i=1If the array is empty, None is returned.
Panics if A::from_usize() fails to convert the number of elements in the array.
Sourcepub fn product(&self) -> A
pub fn product(&self) -> A
Return the product of all elements in the array.
use ndarray::arr2;
let a = arr2(&[[1., 2.],
[3., 4.]]);
assert_eq!(a.product(), 24.);Sourcepub fn cumprod(&self, axis: Axis) -> ArrayBase<OwnedRepr<A>, D>
pub fn cumprod(&self, axis: Axis) -> ArrayBase<OwnedRepr<A>, D>
Return the cumulative product of elements along a given axis.
use ndarray::{arr2, Axis};
let a = arr2(&[[1., 2., 3.],
[4., 5., 6.]]);
// Cumulative product along rows (axis 0)
assert_eq!(
a.cumprod(Axis(0)),
arr2(&[[1., 2., 3.],
[4., 10., 18.]])
);
// Cumulative product along columns (axis 1)
assert_eq!(
a.cumprod(Axis(1)),
arr2(&[[1., 2., 6.],
[4., 20., 120.]])
);Panics if axis is out of bounds.
Sourcepub fn var(&self, ddof: A) -> Awhere
A: Float + FromPrimitive,
pub fn var(&self, ddof: A) -> Awhere
A: Float + FromPrimitive,
Return variance of elements in the array.
The variance is computed using the Welford one-pass algorithm.
The parameter ddof specifies the “delta degrees of freedom”. For
example, to calculate the population variance, use ddof = 0, or to
calculate the sample variance, use ddof = 1.
The variance is defined as:
1 n
variance = ―――――――― ∑ (xᵢ - x̅)²
n - ddof i=1where
1 n
x̅ = ― ∑ xᵢ
n i=1and n is the length of the array.
Panics if ddof is less than zero or greater than n
Example
use ndarray::array;
use approx::assert_abs_diff_eq;
let a = array![1., -4.32, 1.14, 0.32];
let var = a.var(1.);
assert_abs_diff_eq!(var, 6.7331, epsilon = 1e-4);Sourcepub fn std(&self, ddof: A) -> Awhere
A: Float + FromPrimitive,
pub fn std(&self, ddof: A) -> Awhere
A: Float + FromPrimitive,
Return standard deviation of elements in the array.
The standard deviation is computed from the variance using the Welford one-pass algorithm.
The parameter ddof specifies the “delta degrees of freedom”. For
example, to calculate the population standard deviation, use ddof = 0,
or to calculate the sample standard deviation, use ddof = 1.
The standard deviation is defined as:
⎛ 1 n ⎞
stddev = sqrt ⎜ ―――――――― ∑ (xᵢ - x̅)²⎟
⎝ n - ddof i=1 ⎠where
1 n
x̅ = ― ∑ xᵢ
n i=1and n is the length of the array.
Panics if ddof is less than zero or greater than n
Example
use ndarray::array;
use approx::assert_abs_diff_eq;
let a = array![1., -4.32, 1.14, 0.32];
let stddev = a.std(1.);
assert_abs_diff_eq!(stddev, 2.59483, epsilon = 1e-4);Sourcepub fn sum_axis(
&self,
axis: Axis,
) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
pub fn sum_axis( &self, axis: Axis, ) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
Return sum along axis.
use ndarray::{aview0, aview1, arr2, Axis};
let a = arr2(&[[1., 2., 3.],
[4., 5., 6.]]);
assert!(
a.sum_axis(Axis(0)) == aview1(&[5., 7., 9.]) &&
a.sum_axis(Axis(1)) == aview1(&[6., 15.]) &&
a.sum_axis(Axis(0)).sum_axis(Axis(0)) == aview0(&21.)
);Panics if axis is out of bounds.
Sourcepub fn product_axis(
&self,
axis: Axis,
) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
pub fn product_axis( &self, axis: Axis, ) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
Return product along axis.
The product of an empty array is 1.
use ndarray::{aview0, aview1, arr2, Axis};
let a = arr2(&[[1., 2., 3.],
[4., 5., 6.]]);
assert!(
a.product_axis(Axis(0)) == aview1(&[4., 10., 18.]) &&
a.product_axis(Axis(1)) == aview1(&[6., 120.]) &&
a.product_axis(Axis(0)).product_axis(Axis(0)) == aview0(&720.)
);Panics if axis is out of bounds.
Sourcepub fn mean_axis(
&self,
axis: Axis,
) -> Option<ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>>
pub fn mean_axis( &self, axis: Axis, ) -> Option<ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>>
Return mean along axis.
Return None if the length of the axis is zero.
Panics if axis is out of bounds or if A::from_usize()
fails for the axis length.
use ndarray::{aview0, aview1, arr2, Axis};
let a = arr2(&[[1., 2., 3.],
[4., 5., 6.]]);
assert!(
a.mean_axis(Axis(0)).unwrap() == aview1(&[2.5, 3.5, 4.5]) &&
a.mean_axis(Axis(1)).unwrap() == aview1(&[2., 5.]) &&
a.mean_axis(Axis(0)).unwrap().mean_axis(Axis(0)).unwrap() == aview0(&3.5)
);Sourcepub fn var_axis(
&self,
axis: Axis,
ddof: A,
) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
pub fn var_axis( &self, axis: Axis, ddof: A, ) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
Return variance along axis.
The variance is computed using the Welford one-pass algorithm.
The parameter ddof specifies the “delta degrees of freedom”. For
example, to calculate the population variance, use ddof = 0, or to
calculate the sample variance, use ddof = 1.
The variance is defined as:
1 n
variance = ―――――――― ∑ (xᵢ - x̅)²
n - ddof i=1where
1 n
x̅ = ― ∑ xᵢ
n i=1and n is the length of the axis.
Panics if ddof is less than zero or greater than n, if axis
is out of bounds, or if A::from_usize() fails for any any of the
numbers in the range 0..=n.
Example
use ndarray::{aview1, arr2, Axis};
let a = arr2(&[[1., 2.],
[3., 4.],
[5., 6.]]);
let var = a.var_axis(Axis(0), 1.);
assert_eq!(var, aview1(&[4., 4.]));Sourcepub fn std_axis(
&self,
axis: Axis,
ddof: A,
) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
pub fn std_axis( &self, axis: Axis, ddof: A, ) -> ArrayBase<OwnedRepr<A>, <D as Dimension>::Smaller>
Return standard deviation along axis.
The standard deviation is computed from the variance using the Welford one-pass algorithm.
The parameter ddof specifies the “delta degrees of freedom”. For
example, to calculate the population standard deviation, use ddof = 0,
or to calculate the sample standard deviation, use ddof = 1.
The standard deviation is defined as:
⎛ 1 n ⎞
stddev = sqrt ⎜ ―――――――― ∑ (xᵢ - x̅)²⎟
⎝ n - ddof i=1 ⎠where
1 n
x̅ = ― ∑ xᵢ
n i=1and n is the length of the axis.
Panics if ddof is less than zero or greater than n, if axis
is out of bounds, or if A::from_usize() fails for any any of the
numbers in the range 0..=n.
Example
use ndarray::{aview1, arr2, Axis};
let a = arr2(&[[1., 2.],
[3., 4.],
[5., 6.]]);
let stddev = a.std_axis(Axis(0), 1.);
assert_eq!(stddev, aview1(&[2., 2.]));Sourcepub fn diff(&self, n: usize, axis: Axis) -> ArrayBase<OwnedRepr<A>, D>
pub fn diff(&self, n: usize, axis: Axis) -> ArrayBase<OwnedRepr<A>, D>
Calculates the (forward) finite differences of order n, along the axis.
For the 1D-case, n==1, this means: diff[i] == arr[i+1] - arr[i]
For n>=2, the process is iterated:
use ndarray::{array, Axis};
let arr = array![1.0, 2.0, 5.0];
assert_eq!(arr.diff(2, Axis(0)), arr.diff(1, Axis(0)).diff(1, Axis(0)))Panics if axis is out of bounds
Panics if n is too big / the array is to short:
use ndarray::{array, Axis};
array![1.0, 2.0, 3.0].diff(10, Axis(0));Sourcepub fn is_nan(&self) -> ArrayBase<OwnedRepr<bool>, D>
pub fn is_nan(&self) -> ArrayBase<OwnedRepr<bool>, D>
If the number is NaN (not a number), then true is returned for each element.
Sourcepub fn is_all_nan(&self) -> bool
pub fn is_all_nan(&self) -> bool
Return true if all elements are NaN (not a number).
Sourcepub fn is_any_nan(&self) -> bool
pub fn is_any_nan(&self) -> bool
Return true if any element is NaN (not a number).
Sourcepub fn is_infinite(&self) -> ArrayBase<OwnedRepr<bool>, D>
pub fn is_infinite(&self) -> ArrayBase<OwnedRepr<bool>, D>
If the number is infinity, then true is returned for each element.
Sourcepub fn is_all_infinite(&self) -> bool
pub fn is_all_infinite(&self) -> bool
Return true if all elements are infinity.
Sourcepub fn is_any_infinite(&self) -> bool
pub fn is_any_infinite(&self) -> bool
Return true if any element is infinity.
Sourcepub fn floor(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn floor(&self) -> ArrayBase<OwnedRepr<A>, D>
The largest integer less than or equal to each element.
Sourcepub fn ceil(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn ceil(&self) -> ArrayBase<OwnedRepr<A>, D>
The smallest integer less than or equal to each element.
Sourcepub fn signum(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn signum(&self) -> ArrayBase<OwnedRepr<A>, D>
Sign number of each element.
1.0for all positive numbers.-1.0for all negative numbers.NaNfor allNaN(not a number).
Sourcepub fn recip(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn recip(&self) -> ArrayBase<OwnedRepr<A>, D>
The reciprocal (inverse) of each element, 1/x.
Sourcepub fn acos(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn acos(&self) -> ArrayBase<OwnedRepr<A>, D>
Arccosine of each element (return in radians).
Sourcepub fn atan(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn atan(&self) -> ArrayBase<OwnedRepr<A>, D>
Arctangent of each element (return in radians).
Sourcepub fn to_degrees(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn to_degrees(&self) -> ArrayBase<OwnedRepr<A>, D>
Converts radians to degrees for each element.
Sourcepub fn to_radians(&self) -> ArrayBase<OwnedRepr<A>, D>
pub fn to_radians(&self) -> ArrayBase<OwnedRepr<A>, D>
Converts degrees to radians for each element.
Sourcepub fn powi(&self, rhs: i32) -> ArrayBase<OwnedRepr<A>, D>
pub fn powi(&self, rhs: i32) -> ArrayBase<OwnedRepr<A>, D>
Integer power of each element.
This function is generally faster than using float power.
Sourcepub fn log(&self, rhs: A) -> ArrayBase<OwnedRepr<A>, D>
pub fn log(&self, rhs: A) -> ArrayBase<OwnedRepr<A>, D>
Logarithm of each element with respect to an arbitrary base.
Sourcepub fn abs_sub(&self, rhs: A) -> ArrayBase<OwnedRepr<A>, D>
pub fn abs_sub(&self, rhs: A) -> ArrayBase<OwnedRepr<A>, D>
The positive difference between given number and each element.
Sourcepub fn hypot(&self, rhs: A) -> ArrayBase<OwnedRepr<A>, D>
pub fn hypot(&self, rhs: A) -> ArrayBase<OwnedRepr<A>, D>
Length of the hypotenuse of a right-angle triangle of each element
Sourcepub fn clamp(&self, min: A, max: A) -> ArrayBase<OwnedRepr<A>, D>
pub fn clamp(&self, min: A, max: A) -> ArrayBase<OwnedRepr<A>, D>
Limit the values for each element, similar to NumPy’s clip function.
use ndarray::array;
let a = array![0., 1., 2., 3., 4., 5., 6., 7., 8., 9.];
assert_eq!(a.clamp(1., 8.), array![1., 1., 2., 3., 4., 5., 6., 7., 8., 8.]);
assert_eq!(a.clamp(3., 6.), array![3., 3., 3., 3., 4., 5., 6., 6., 6., 6.]);Panics
Panics if !(min <= max).
Sourcepub fn triu(&self, k: isize) -> ArrayBase<OwnedRepr<A>, D>
pub fn triu(&self, k: isize) -> ArrayBase<OwnedRepr<A>, D>
Upper triangular of an array.
Return a copy of the array with elements below the k-th diagonal zeroed.
For arrays with ndim exceeding 2, triu will apply to the final two axes.
For 0D and 1D arrays, triu will return an unchanged clone.
See also ArrayRef::tril
use ndarray::array;
let arr = array![
[1, 2, 3],
[4, 5, 6],
[7, 8, 9]
];
assert_eq!(
arr.triu(0),
array![
[1, 2, 3],
[0, 5, 6],
[0, 0, 9]
]
);Sourcepub fn tril(&self, k: isize) -> ArrayBase<OwnedRepr<A>, D>
pub fn tril(&self, k: isize) -> ArrayBase<OwnedRepr<A>, D>
Lower triangular of an array.
Return a copy of the array with elements above the k-th diagonal zeroed.
For arrays with ndim exceeding 2, tril will apply to the final two axes.
For 0D and 1D arrays, tril will return an unchanged clone.
See also ArrayRef::triu
use ndarray::array;
let arr = array![
[1, 2, 3],
[4, 5, 6],
[7, 8, 9]
];
assert_eq!(
arr.tril(0),
array![
[1, 0, 0],
[4, 5, 0],
[7, 8, 9]
]
);Methods from Deref<Target = RawRef<A, D>>
Sourcepub fn get_ptr<I>(&self, index: I) -> Option<*const A>where
I: NdIndex<D>,
pub fn get_ptr<I>(&self, index: I) -> Option<*const A>where
I: NdIndex<D>,
Return a raw pointer to the element at index, or return None
if the index is out of bounds.
use ndarray::arr2;
let a = arr2(&[[1., 2.], [3., 4.]]);
let v = a.raw_view();
let p = a.get_ptr((0, 1)).unwrap();
assert_eq!(unsafe { *p }, 2.);Sourcepub fn get_mut_ptr<I>(&mut self, index: I) -> Option<*mut A>where
I: NdIndex<D>,
pub fn get_mut_ptr<I>(&mut self, index: I) -> Option<*mut A>where
I: NdIndex<D>,
Return a raw pointer to the element at index, or return None
if the index is out of bounds.
use ndarray::arr2;
let mut a = arr2(&[[1., 2.], [3., 4.]]);
let v = a.raw_view_mut();
let p = a.get_mut_ptr((0, 1)).unwrap();
unsafe {
*p = 5.;
}
assert_eq!(a.get((0, 1)), Some(&5.));Sourcepub fn as_ptr(&self) -> *const A
pub fn as_ptr(&self) -> *const A
Return a pointer to the first element in the array.
Raw access to array elements needs to follow the strided indexing scheme: an element at multi-index I in an array with strides S is located at offset
Σ0 ≤ k < d Ik × Sk
where d is self.ndim().
Sourcepub fn as_mut_ptr(&mut self) -> *mut A
pub fn as_mut_ptr(&mut self) -> *mut A
Return a mutable pointer to the first element in the array reference.
Sourcepub fn raw_view(&self) -> ArrayBase<RawViewRepr<*const A>, D>
pub fn raw_view(&self) -> ArrayBase<RawViewRepr<*const A>, D>
Return a raw view of the array.
Sourcepub fn raw_view_mut(&mut self) -> ArrayBase<RawViewRepr<*mut A>, D>
pub fn raw_view_mut(&mut self) -> ArrayBase<RawViewRepr<*mut A>, D>
Return a raw mutable view of the array.
Methods from Deref<Target = LayoutRef<A, D>>
Sourcepub fn len_of(&self, axis: Axis) -> usize
pub fn len_of(&self, axis: Axis) -> usize
Return the length of axis.
The axis should be in the range Axis( 0 .. n ) where n is the
number of dimensions (axes) of the array.
Panics if the axis is out of bounds.
Sourcepub fn dim(&self) -> <D as Dimension>::Pattern
pub fn dim(&self) -> <D as Dimension>::Pattern
Return the shape of the array in its “pattern” form, an integer in the one-dimensional case, tuple in the n-dimensional cases and so on.
Sourcepub fn raw_dim(&self) -> D
pub fn raw_dim(&self) -> D
Return the shape of the array as it’s stored in the array.
This is primarily useful for passing to other ArrayBase
functions, such as when creating another array of the same
shape and dimensionality.
use ndarray::Array;
let a = Array::from_elem((2, 3), 5.);
// Create an array of zeros that's the same shape and dimensionality as `a`.
let b = Array::<f64, _>::zeros(a.raw_dim());Sourcepub fn shape(&self) -> &[usize]
pub fn shape(&self) -> &[usize]
Return the shape of the array as a slice.
Note that you probably don’t want to use this to create an array of the
same shape as another array because creating an array with e.g.
Array::zeros() using a shape of type &[usize]
results in a dynamic-dimensional array. If you want to create an array
that has the same shape and dimensionality as another array, use
.raw_dim() instead:
use ndarray::{Array, Array2};
let a = Array2::<i32>::zeros((3, 4));
let shape = a.shape();
assert_eq!(shape, &[3, 4]);
// Since `a.shape()` returned `&[usize]`, we get an `ArrayD` instance:
let b = Array::zeros(shape);
assert_eq!(a.clone().into_dyn(), b);
// To get the same dimension type, use `.raw_dim()` instead:
let c = Array::zeros(a.raw_dim());
assert_eq!(a, c);Sourcepub fn stride_of(&self, axis: Axis) -> isize
pub fn stride_of(&self, axis: Axis) -> isize
Return the stride of axis.
The axis should be in the range Axis( 0 .. n ) where n is the
number of dimensions (axes) of the array.
Panics if the axis is out of bounds.
Sourcepub fn slice_collapse<I>(&mut self, info: I)where
I: SliceArg<D>,
pub fn slice_collapse<I>(&mut self, info: I)where
I: SliceArg<D>,
Slice the array in place without changing the number of dimensions.
In particular, if an axis is sliced with an index, the axis is
collapsed, as in .collapse_axis(), rather than removed, as in
.slice_move() or .index_axis_move().
See Slicing for full documentation.
See also s!, SliceArg, and SliceInfo.
Panics in the following cases:
- if an index is out of bounds
- if a step size is zero
- if
SliceInfoElem::NewAxisis ininfo, e.g. ifNewAxiswas used in thes!macro - if
DisIxDynandinfodoes not match the number of array axes
Sourcepub fn slice_axis_inplace(&mut self, axis: Axis, indices: Slice)
pub fn slice_axis_inplace(&mut self, axis: Axis, indices: Slice)
Slice the array in place along the specified axis.
Panics if an index is out of bounds or step size is zero.
Panics if axis is out of bounds.
Sourcepub fn slice_each_axis_inplace<F>(&mut self, f: F)
pub fn slice_each_axis_inplace<F>(&mut self, f: F)
Slice the array in place, with a closure specifying the slice for each axis.
This is especially useful for code which is generic over the dimensionality of the array.
Panics if an index is out of bounds or step size is zero.
Sourcepub fn collapse_axis(&mut self, axis: Axis, index: usize)
pub fn collapse_axis(&mut self, axis: Axis, index: usize)
Selects index along the axis, collapsing the axis into length one.
Panics if axis or index is out of bounds.
Sourcepub fn is_standard_layout(&self) -> bool
pub fn is_standard_layout(&self) -> bool
Return true if the array data is laid out in contiguous “C order” in
memory (where the last index is the most rapidly varying).
Return false otherwise, i.e. the array is possibly not
contiguous in memory, it has custom strides, etc.
Sourcepub fn swap_axes(&mut self, ax: usize, bx: usize)
pub fn swap_axes(&mut self, ax: usize, bx: usize)
Swap axes ax and bx.
This does not move any data, it just adjusts the array’s dimensions and strides.
Panics if the axes are out of bounds.
use ndarray::arr2;
let mut a = arr2(&[[1., 2., 3.]]);
a.swap_axes(0, 1);
assert!(
a == arr2(&[[1.], [2.], [3.]])
);Sourcepub fn max_stride_axis(&self) -> Axis
pub fn max_stride_axis(&self) -> Axis
Return the axis with the greatest stride (by absolute value), preferring axes with len > 1.
Sourcepub fn invert_axis(&mut self, axis: Axis)
pub fn invert_axis(&mut self, axis: Axis)
Reverse the stride of axis.
Panics if the axis is out of bounds.
Sourcepub fn merge_axes(&mut self, take: Axis, into: Axis) -> bool
pub fn merge_axes(&mut self, take: Axis, into: Axis) -> bool
If possible, merge in the axis take to into.
Returns true iff the axes are now merged.
This method merges the axes if movement along the two original axes
(moving fastest along the into axis) can be equivalently represented
as movement along one (merged) axis. Merging the axes preserves this
order in the merged axis. If take and into are the same axis, then
the axis is “merged” if its length is ≤ 1.
If the return value is true, then the following hold:
-
The new length of the
intoaxis is the product of the original lengths of the two axes. -
The new length of the
takeaxis is 0 if the product of the original lengths of the two axes is 0, and 1 otherwise.
If the return value is false, then merging is not possible, and the
original shape and strides have been preserved.
Note that the ordering constraint means that if it’s possible to merge
take into into, it’s usually not possible to merge into into
take, and vice versa.
use ndarray::Array3;
use ndarray::Axis;
let mut a = Array3::<f64>::zeros((2, 3, 4));
assert!(a.merge_axes(Axis(1), Axis(2)));
assert_eq!(a.shape(), &[2, 1, 12]);Panics if an axis is out of bounds.