Structs
- Bernoulli
Marginal Slope Predictor - Binomial
Location Scale Predictor - Binomial location-scale predictor: two blocks (threshold + log-sigma).
- Coefficient
Uncertainty Result - Gaussian
Location Scale Predictor - Gaussian location-scale predictor: two blocks (mean + log-sigma).
- Predict
Input - Input to the prediction trait. Contains the design matrix and metadata needed for point prediction + uncertainty quantification.
- Predict
Posterior Mean Result - Predict
Result - Predict
Uncertainty Options - Predict
Uncertainty Result - Prediction
WithSE - Point prediction with optional standard errors on the linear predictor.
- Standard
Predictor - Standard (single-block) GAM predictor.
- Survival
Predictor - Training
Support - Per-axis training support range used by boundary and OOD corrections. For each predictor axis we record the empirical [min, max] from training. Boundary correction inflates variance for x_i within a small fraction of the range from either edge; OOD inflation inflates variance for x_i outside [min, max] proportional to (excess / range).
- Transformation
Normal Predictor - Predictor for transformation-normal (PIT) models.
Enums
Traits
- Predictable
Model - Trait for models that can produce predictions from new data.
Functions
- coefficient_
uncertainty - Coefficient-level uncertainty and confidence intervals.
- coefficient_
uncertaintywith_ mode - Coefficient-level uncertainty and confidence intervals with explicit covariance mode.
- enrich_
posterior_ mean_ bounds - Compute and attach TransformEta confidence bounds to a posterior-mean result.
- predict_
gam - Generic engine prediction for external designs. This API is domain-agnostic: callers provide only design matrix, coefficients, offset, and family.
- predict_
gam_ posterior_ mean - Nonlinear posterior-mean prediction with coefficient uncertainty propagation.
- predict_
gam_ posterior_ meanwith_ backend - predict_
gam_ posterior_ meanwith_ fit - Nonlinear posterior-mean prediction with link-state support for SAS/mixture families.
- predict_
gamwith_ uncertainty - Prediction with coefficient uncertainty propagation.
- se_
from_ covariance - Compute standard errors from a covariance matrix (sqrt of diagonal).